@@ -1,10 +1,7 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>dock::MultiTaskView</name>
     <message>
-        <location filename="../multitaskview.cpp" line="65"/>
         <source>Multitasking View</source>
         <translation>多任务视图</translation>
     </message>
@@ -12,9 +9,8 @@
 <context>
     <name>multitaskview</name>
     <message>
-        <location filename="../package/multitaskview.qml" line="23"/>
         <source>Multitasking View</source>
         <translation>多任务视图</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
