@@ -1,12 +1,9 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>showdesktop</name>
     <message>
-        <location filename="../package/showdesktop.qml" line="45"/>
         <source>show desktop</source>
         <translation>显示桌面</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
