@@ -12,8 +12,7 @@
 
 #include <fstream>
 
-Q_LOGGING_CATEGORY(abstractdesktopfileLog, "dde.shell.dock.abstractdesktopfile")
-
+Q_LOGGING_CATEGORY(abstractdesktopfileLog, "org.deepin.dde.shell.dock.abstractdesktopfile")
 
 namespace dock {
 
@@ -34,11 +33,12 @@ void DesktopfileAbstractParser::launch()
 
 void DesktopfileAbstractParser::launchWithAction(const QString& action)
 {
-
+    Q_UNUSED(action)
 }
 
 void DesktopfileAbstractParser::launchWithUrls(const QStringList & urls)
 {
+    Q_UNUSED(urls)
 }
 
 void DesktopfileAbstractParser::requestQuit()
@@ -134,10 +134,7 @@ bool DesktopfileAbstractParser::isDocked()
         return false;
     }
 
-    QJsonObject desktopfile;
-    desktopfile["type"] = type();
-    desktopfile["id"] = id();
-    return TaskManagerSettings::instance()->dockedDesktopFiles().contains(desktopfile);
+    return TaskManagerSettings::instance()->isDocked(QStringLiteral("desktop/%1").arg(id()));
 }
 
 void DesktopfileAbstractParser::setDocked(bool docked)
@@ -147,14 +144,12 @@ void DesktopfileAbstractParser::setDocked(bool docked)
         return;
     }
 
-    QJsonObject desktopfile;
-    desktopfile["type"] = type();
-    desktopfile["id"] = id();
+    auto desktopElement = QStringLiteral("desktop/%1").arg(id());
 
     if (docked) {
-        TaskManagerSettings::instance()->appnedDockedDesktopfiles(desktopfile);
+        TaskManagerSettings::instance()->appendDockedElement(desktopElement);
     } else {
-        TaskManagerSettings::instance()->removeDockedDesktopfile(desktopfile);
+        TaskManagerSettings::instance()->removeDockedElement(desktopElement);
     }
 
     Q_EMIT dockedChanged();
