@@ -24,18 +24,18 @@
 #include <QGuiApplication>
 #include <QStringLiteral>
 #include <QUrl>
-#include <QDir>
 #include <QStandardPaths>
-#include <DTrashManager>
+#include <QProcess>
 
 #include <appletbridge.h>
+#include <DSGApplication>
 
 #ifdef BUILD_WITH_X11
 #include "x11windowmonitor.h"
 #include "x11utils.h"
 #endif
 
-Q_LOGGING_CATEGORY(taskManagerLog, "dde.shell.dock.taskmanager", QtDebugMsg)
+Q_LOGGING_CATEGORY(taskManagerLog, "org.deepin.dde.shell.dock.taskmanager", QtDebugMsg)
 
 #define Settings TaskManagerSettings::instance()
 
@@ -46,6 +46,25 @@ Q_LOGGING_CATEGORY(taskManagerLog, "dde.shell.dock.taskmanager", QtDebugMsg)
 
 namespace dock {
 
+// 通过AM(Application Manager)匹配应用程序的辅助函数
+static QString getDesktopIdByPid(const QStringList &identifies)
+{
+    if (identifies.isEmpty())
+        return {};
+
+    pid_t windowPid = identifies.last().toInt();
+    if (windowPid <= 0)
+        return {};
+
+    auto appId = DSGApplication::getId(windowPid);
+    if (appId.isEmpty()) {
+        qCDebug(taskManagerLog) << "appId is empty, AM failed to identify window with pid:" << windowPid;
+        return {};
+    }
+        
+    return QString::fromUtf8(appId);
+}
+
 class BoolFilterModel : public QSortFilterProxyModel, public AbstractTaskManagerInterface
 {
     Q_OBJECT
@@ -56,6 +75,7 @@ public:
         , m_role(role)
     {
         setSourceModel(sourceModel);
+        setDynamicSortFilter(false);
     }
 
 protected:
@@ -131,6 +151,18 @@ bool TaskManager::init()
                 }
             }
 
+            // 尝试通过AM(Application Manager)匹配应用程序
+            if (Settings->cgroupsBasedGrouping()) {
+                auto desktopId = getDesktopIdByPid(identifies);
+                if (!desktopId.isEmpty() && !Settings->cgroupsBasedGroupingSkipIds().contains(desktopId)) {
+                    auto res = model->match(model->index(0, 0), roleNames.key(MODEL_DESKTOPID), desktopId, 1, Qt::MatchFixedString | Qt::MatchWrap).value(0);
+                    if (res.isValid()) {
+                        qCDebug(taskManagerLog) << "matched by AM desktop ID:" << desktopId << res;
+                        return res;
+                    }
+                }
+            }
+
             auto res = model->match(model->index(0, 0), roleNames.key(MODEL_DESKTOPID), identifies.value(0), 1, Qt::MatchEndsWith);
             qCDebug(taskManagerLog) << "matched" << res.value(0);
             return res.value(0);
@@ -216,7 +248,13 @@ void TaskManager::requestPreview(const QModelIndex &index, QObject *relativePosi
     }
 
     // Set the preview filter condition based on the incoming model index
-    m_hoverPreviewModel->setFilterModelIndex(index);
+    if (windowSplit()) {
+        QString winId = index.data(TaskManager::WinIdRole).toString();
+        m_hoverPreviewModel->setFilter(winId, HoverPreviewProxyModel::FilterByWinId);
+    } else {
+        QString appId = index.data(TaskManager::DesktopIdRole).toString();
+        m_hoverPreviewModel->setFilter(appId, HoverPreviewProxyModel::FilterByAppId);
+    }
 
     // Check if there are any windows after filtering
     if (m_hoverPreviewModel->rowCount() == 0) {
@@ -275,13 +313,6 @@ void TaskManager::handleWindowAdded(QPointer<AbstractWindow> window)
 
 void TaskManager::dropFilesOnItem(const QString& itemId, const QStringList& urls)
 {
-    if (itemId == "dde-trash") {
-        qCDebug(taskManagerLog) << "dropFilesOnItem: dde-trash - moving files to trash:" << urls;
-        // 将文件移动到回收站
-        moveFilesToTrash(urls);
-        return;
-    }
-
     auto indexes = m_itemModel->match(m_itemModel->index(0, 0), TaskManager::ItemIdRole, itemId, 1, Qt::MatchExactly);
     if (indexes.isEmpty()) {
         return;
@@ -295,20 +326,6 @@ void TaskManager::dropFilesOnItem(const QString& itemId, const QStringList& urls
     m_itemModel->requestOpenUrls(indexes.first(), urlList);
 }
 
-void TaskManager::moveFilesToTrash(const QStringList& urls)
-{
-    // 将文件路径转换为本地路径并移动到回收站
-    for (const QString& urlString : urls) {
-        QUrl url(urlString);
-        QString filePath = url.toLocalFile();
-        if (DTrashManager::instance()->moveToTrash(filePath)) {
-            qCDebug(taskManagerLog) << "Successfully moved to trash:" << filePath;
-        } else {
-            qCWarning(taskManagerLog) << "Failed to move to trash:" << filePath;
-        }
-    }
-}
-
 void TaskManager::hideItemPreview()
 {
     m_windowMonitor->hideItemPreview();
@@ -429,16 +446,30 @@ void TaskManager::saveDockElementsOrder(const QStringList &appIds)
 
 QString TaskManager::getTrashTipText()
 {
-    int fileCount = 0;
-    QString trashPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/Trash/files";
-    QDir trashDir(trashPath);
-    
-    if (trashDir.exists()) {
-        QStringList entries = trashDir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot);
-        fileCount = entries.size();
-    }
+    const auto count = queryTrashCount();
+    return tr("%1 files").arg(count);
+}
 
-    return tr("%1 files").arg(fileCount);
+bool TaskManager::isTrashEmpty() const
+{
+    return queryTrashCount() == 0;
+}
+
+int TaskManager::queryTrashCount() const
+{
+    int count = 0;
+
+    QProcess gio;
+    gio.start("gio", QStringList() << "trash" << "--list");
+    if (gio.waitForFinished(1000) && gio.exitStatus() == QProcess::NormalExit && gio.exitCode() == 0) {
+        const QByteArray &out = gio.readAllStandardOutput();
+        const QList<QByteArray> lines = out.split('\n');
+        for (const QByteArray &l : lines) {
+            if (!l.trimmed().isEmpty()) count++;
+        }
+        return count;
+    }
+    return count;
 }
 
 void TaskManager::modifyOpacityChanged()
