@@ -1,10 +1,27 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="fi">
 <context>
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
         <translation>Tyhjennä kaikki</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Taita</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Lisää</translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation>Ei viimeaikaisia ilmoituksia</translation>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +33,14 @@
         <source>Clear All</source>
         <translation>Tyhjennä kaikki</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation>Taita</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Lisää</translation>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -32,27 +57,18 @@
         <translation>Ilmoitusten asetukset</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation type="unfinished">Puhdista kaikki</translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Juuri nyt</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 min sitten</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>1 h sitten</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1 h sitten</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Eilen</translation>
-    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
