@@ -1,10 +1,27 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="hu">
 <context>
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
         <translation>Összes törlése</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NotifyHeader</name>
@@ -16,6 +33,14 @@
         <source>Clear All</source>
         <translation>Összes törlése</translation>
     </message>
+    <message>
+        <source>Fold</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NotifySetting</name>
@@ -32,27 +57,18 @@
         <translation>Értesítési Beállítások</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Csak most</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 perccel ezelőtt</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1 órával ezelőtt</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Tegnap</translation>
-    </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
