@@ -3,7 +3,22 @@
     <name>GroupNotify</name>
     <message>
         <source>Clear All</source>
-        <translation>Wyczyść wszystko</translation>
+        <translation>Wyczyść wszystkie</translation>
+    </message>
+    <message>
+        <source>Fold</source>
+        <translation>Zwiń</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Więcej</translation>
+    </message>
+</context>
+<context>
+    <name>NotifyCenter</name>
+    <message>
+        <source>No recent notifications</source>
+        <translation>Brak nowych powiadomień</translation>
     </message>
 </context>
 <context>
@@ -14,7 +29,15 @@
     </message>
     <message>
         <source>Clear All</source>
-        <translation>Wyczyść wszystko</translation>
+        <translation>Wyczyść wszystkie</translation>
+    </message>
+    <message>
+        <source>Fold</source>
+        <translation>Zwiń</translation>
+    </message>
+    <message>
+        <source>More</source>
+        <translation>Więcej</translation>
     </message>
 </context>
 <context>
@@ -32,27 +55,18 @@
         <translation>Ustawienia powiadomień</translation>
     </message>
 </context>
+<context>
+    <name>NotifyViewDelegate</name>
+    <message>
+        <source>Clean All</source>
+        <translation>Wyczyść wszystkie</translation>
+    </message>
+</context>
 <context>
     <name>notifycenter::AppNotifyItem</name>
     <message>
         <source>Just now</source>
         <translation>Właśnie teraz</translation>
     </message>
-    <message>
-        <source>%1 minutes ago</source>
-        <translation>%1 minut temu</translation>
-    </message>
-    <message>
-        <source>1 hour ago</source>
-        <translation>1 godzinę temu</translation>
-    </message>
-    <message>
-        <source>%1 hours ago</source>
-        <translation>%1 godzin temu</translation>
-    </message>
-    <message>
-        <source>Yesterday </source>
-        <translation>Wczoraj </translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
